pub enum Record {
New {
collection_id: i32,
activity: Activity,
term_begin: Term,
term_end: Term,
fields: Vec<KeyValue>,
depends: Depends,
pends: Vec<Pend>,
},
Update {
collection_id: i32,
row: i64,
activity: Activity,
term_begin: Term,
term_end: Term,
fields: Vec<KeyValue>,
depends: Depends,
pends: Vec<Pend>,
},
Delete {
collection_id: i32,
row: i64,
},
}
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.